//
//  StringExtensions.m
//  The Fillers
//
//  Created by Richard Jones on 18/03/2011.
//  Copyright 2011 Binary Refinery. All rights reserved.
//

#import "StringExtensions.h"


@implementation NSString (StringExtensions)


- (NSInteger) LastIndexOf:(NSString *)searchstring
{
    
    NSRange start=[self rangeOfString:searchstring options:NSBackwardsSearch];
    if (start.location == NSNotFound) 
        return -1;   
    else
        return start.location;
}

- (NSInteger) LastIndexOfI:(NSString *)searchstring
{
    
    NSRange start=[self rangeOfString:searchstring options:NSBackwardsSearch+NSCaseInsensitiveSearch];
    if (start.location == NSNotFound) 
        return -1;   
    else
        return start.location;
}

- (NSInteger) IndexOf:(NSString *)searchstring
{    
    NSRange start=[self rangeOfString:searchstring];
    if (start.location == NSNotFound) 
        return -1;   
    else
        return start.location;
}


- (NSInteger) IndexOfI:(NSString *)searchstring
{    
    NSRange start=[self rangeOfString:searchstring options:NSCaseInsensitiveSearch];
    if (start.location == NSNotFound) 
        return -1;   
    else
        return start.location;
}

- (NSString *) SubString:(NSInteger)start
{
    NSRange srange=NSMakeRange(start,[self length]-start);

    return [self substringWithRange:srange];
}


- (NSString *) SubString:(NSInteger)start length:(NSInteger)length
{
    NSRange srange=NSMakeRange(start,length);
    
    return [self substringWithRange:srange];
}

-(NSString *) Replace:(NSString *)what with:(NSString *)with
{
    return [self stringByReplacingOccurrencesOfString:what withString:with];
}

-(NSString *) ReplaceI:(NSString *)what with:(NSString *)with
{
    NSRange range = NSMakeRange(0, [self length]);
    return [self stringByReplacingOccurrencesOfString:what withString:with options:NSCaseInsensitiveSearch range:range];
}

-(NSString *) Remove:(NSString *)what
{
    return [self stringByReplacingOccurrencesOfString:what withString:@""];
}

-(NSString *) RemoveI:(NSString *)what
{
    NSRange range = NSMakeRange(0, [self length]);
    return [self stringByReplacingOccurrencesOfString:what withString:@"" options:NSCaseInsensitiveSearch range:range];
}

-(NSString *) Trim
{
   return [self stringByTrimmingCharactersInSet:[NSCharacterSet whitespaceAndNewlineCharacterSet]];
}

- (NSString *) LTrim
{
  
    if ([self length]==0) return self;
    NSInteger i=0;
    
    while (i<[self length])
    {
        unichar thechar = [self characterAtIndex:i];
        if (thechar==' ' || thechar=='\n')
        {
            i++;
        }
        else
        {
            break;
        }
        
    }
        
    return [self SubString:i];
}

- (NSString *) RTrim
{    
    
    NSInteger i=[self length]-1;
    if (i==-1) return self;
    
    while (i>0)
    {
        unichar thechar = [self characterAtIndex:i];
        if (thechar==' ' || thechar=='\n')
        {
            i--;
        }
        else
        {
            break;
        }
        
    }
    
    return [self SubString:0 length:i+1];
}

- (NSArray *) Split:(NSString *)withwhat
{
    NSArray *chunks = [self componentsSeparatedByString: withwhat];
    return chunks;
}

- (NSString *) PadRight:(NSInteger)totallength
{
    if ([self length]>=totallength) return self;
    return [self stringByPaddingToLength:totallength withString: @" " startingAtIndex:0];    
}

- (NSString *) PadLeft:(NSInteger)totallength
{
    if ([self length]>=totallength) return self;
    
    NSString *emptyString = [NSString stringWithString:@""];
	NSString *padString = [emptyString stringByPaddingToLength:totallength-[self length] withString:@" " startingAtIndex:0];
	return [padString stringByAppendingString:self];
}


@end
